@@ -3,15 +3,19 @@ from admin_honeypot.models import LoginAttempt
 from admin_honeypot.signals import honeypot
 from django.contrib.auth import REDIRECT_FIELD_NAME
 from django.contrib.sites.models import Site
-from django.shortcuts import render_to_response
+from django.shortcuts import render_to_response, redirect
 from django.template import RequestContext
 from django.utils.translation import ugettext as _
 
 def admin_honeypot(request, extra_context=None):
+    path = request.get_full_path()
+    if not path.endswith('/'):
+        return redirect(path + '/', permanent=True)
+
     context = {
-        'app_path': request.get_full_path(),
+        'app_path': path,
         'form': HoneypotLoginForm(request, request.POST or None),
-        REDIRECT_FIELD_NAME: request.get_full_path(),
+        REDIRECT_FIELD_NAME: path,
         'site': Site.objects.get_current(),
         'title': _('Log in'),
         }
